@@ -35,12 +35,12 @@ ptxd_make_image_fix_permissions_check() {
     ptxd_check_obsolete_perm "${ptxd_reply_perm_files[@]}"
 
     # just care about dev-nodes, for now
-    egrep -h "^[n]${IFS}" "${ptxd_reply_perm_files[@]}" |
+    grep -E -h "^[n]${IFS}" "${ptxd_reply_perm_files[@]}" |
     while read kind file uid_should gid_should prm_should type major_should minor_should; do
 	local fixup=false
 	file="${workdir}/${file#/}"
 
-	if [ \! -e "${file}" ]; then
+	if [ ! -e "${file}" ]; then
 	    fixup=true
 	else
 	    local uid_is gid_is prm_is
@@ -113,7 +113,7 @@ ptxd_make_image_fix_permissions() {
     exec 3>&-
 
     # nothing to do!
-    if [ \! -s "${fixscript}" ]; then
+    if [ ! -s "${fixscript}" ]; then
 	return
     fi
 
